@@ -79,7 +79,7 @@ class mysql(object):
 			elif dicts[x] is None:
 				data='NULL'
 			else:
-				data='"'+self.pymysql.escape_string(dicts[x])+'"'
+				data='"'+self.pymysql.converters.escape_string(dicts[x])+'"'
 			string+=r' `%s`=%s %s'%(x,data,splitor)
 		return string[:-len(splitor)]
 	def _split_add_dict(self,dicts):
@@ -87,7 +87,7 @@ class mysql(object):
 		for x in dicts:
 			key+=r'`%s`,'%x
 			if dicts[x] is None:value+='null,'
-			else:value+=r'%s,'%(dicts[x]) if is_numeric(dicts[x]) else r'"%s",'%(self.pymysql.escape_string(dicts[x]))
+			else:value+=r'%s,'%(dicts[x]) if is_numeric(dicts[x]) else r'"%s",'%(self.pymysql.converters.escape_string(dicts[x]))
 		return key[:-1],value[:-1]
 	def execute(self,strs):
 		strs=strs.strip()
